import sys

from timeit import Timer


DECODE_TESTS = [
    'yajl',
    'nssjson',
    'json',
    'rapidjson',
    'simplejson',
    'ujson',
    'orjson',
    'mujson'
]


ENCODE_TESTS = [
    'simplejson',
    'nssjson',
    'json',
    'yajl',
    'ujson',
    'rapidjson',
    'metamagic.json',
    'orjson',
    'mujson'
]


DECODE_ENCODE_TESTS = [
    'nssjson',
    'simplejson',
    'yajl',
    'json',
    'rapidjson',
    'ujson',
    'orjson',
    'mujson'
]


ACTIONS = {
    'decoded': 'loads(bin)',
    'encoded': 'dumps(obj)',
    'de/encoded': 'dumps(loads(bin))'
}


ASCII_BREAK = '\n' + '*' * 75 + '\n'


_import_tpl = 'from {} import (dumps, loads)'


_bin_tmpl = "bin = open('json/{}', 'r').read()"


_obj = "obj = loads(bin)"


_warm_up = "loads(dumps([]))"


def timeit(mod, act, num, jsn, import_stmt):
    setup = [import_stmt, _warm_up, _bin_tmpl.format(jsn), _obj]
    try:
        msecs = Timer(ACTIONS[act], '; '.join(setup)).timeit(num) * 1000
        print(f'{mod:15s} {act} {jsn} {num} times in {msecs} milliseconds!')
    except:
        print(f'{mod:15s} threw Exception trying to {act} {jsn} {num} times!')


def main(number, jsn):
    print(ASCII_BREAK)

    for module in DECODE_TESTS:
        timeit(module, 'decoded', number, jsn, _import_tpl.format(module))

    print(ASCII_BREAK)

    for module in ENCODE_TESTS:
        timeit(module, 'encoded', number, jsn, _import_tpl.format(module))

    print(ASCII_BREAK)

    for module in DECODE_ENCODE_TESTS:
        timeit(module, 'de/encoded', number, jsn, _import_tpl.format(module))

    print(ASCII_BREAK)


if __name__ == '__main__':
    if len(sys.argv) == 3:
        main(int(sys.argv[1]), sys.argv[2])



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import io
import re

from setuptools import (find_packages, setup)

with io.open('README.md', 'rt', encoding='utf8') as fp:
    readme = fp.read()

with io.open('mujson/__init__.py', 'rt', encoding='utf8') as fp:
    version = re.search(r'__version__ = \'(.*?)\'', fp.read()).group(1)

setup(
    name='mujson',
    version=version,
    url='https://github.com/mattgiles/mujson',
    license='MIT',
    author='Matt Giles',
    author_email='matt.s.giles@gmail.com',
    description='Use the fastest JSON functions available at import time.',
    long_description=readme,
    packages=['mujson'],
    include_package_data=False,
    zip_safe=False,
    platforms='any',
    keywords='json',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: Implementation :: CPython',
        'Programming Language :: Python :: Implementation :: PyPy',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6'
    ]
)



import sys

from timeit import Timer


DECODE_TESTS = [
    ('json', 'loads', 'dumps'),
    ('yajl', 'loads', 'dumps'),
    ('nssjson', 'loads', 'dumps'),
    ('simplejson', 'loads', 'dumps'),
    ('ujson', 'loads', 'dumps'),
    ('cjson', 'decode', 'encode'),
    ('mujson', 'loads', 'dumps')
]


ENCODE_TESTS = [
    ('simplejson', 'loads', 'dumps'),
    ('nssjson', 'loads', 'dumps'),
    ('cjson', 'decode', 'encode'),
    ('json', 'loads', 'dumps'),
    ('yajl', 'loads', 'dumps'),
    ('ujson', 'loads', 'dumps'),
    ('mujson', 'loads', 'dumps')
]


DECODE_ENCODE_TESTS = [
    ('json', 'loads', 'dumps'),
    ('yajl', 'loads', 'dumps'),
    ('nssjson', 'loads', 'dumps'),
    ('simplejson', 'loads', 'dumps'),
    ('ujson', 'loads', 'dumps'),
    ('cjson', 'decode', 'encode'),
    ('mujson', 'loads', 'dumps')
]


ACTIONS = {
    'decoded': 'loads(bin)',
    'encoded': 'dumps(obj)',
    'de/encoded': 'dumps(loads(bin))'
}


ASCII_BREAK = '\n' + '*' * 75 + '\n'


_import_tpl = 'from {} import ({} as loads, {} as dumps)'


_bin_tmpl = "bin = open('json/{}', 'rb').read()"


_obj = "obj = loads(bin)"


_warm_up = "loads(dumps([]))"


def timeit(module, action, num, jsn, import_stmt):
    setup = [import_stmt, _warm_up, _bin_tmpl.format(jsn), _obj]
    try:
        result = Timer(ACTIONS[action], '; '.join(setup)).timeit(num) * 1000
        print('{:25s} {} {} {} times in {} milliseconds.'.format(
            module, action, jsn, num, result))
    except:
        raise
        print('{:25s} threw Exception trying to {} {} {} times.'.format(
            module, action, jsn, num))


def main(number, jsn):
    print(ASCII_BREAK)

    for module, decoder, encoder in DECODE_TESTS:
        import_stmt = _import_tpl.format(module, decoder, encoder)
        timeit(module, 'decoded', number, jsn, import_stmt)

    print(ASCII_BREAK)

    for module, decoder, encoder in ENCODE_TESTS:
        import_stmt = _import_tpl.format(module, decoder, encoder)
        timeit(module, 'encoded', number, jsn, import_stmt)

    print(ASCII_BREAK)

    for module, decoder, encoder in DECODE_ENCODE_TESTS:
        import_stmt = _import_tpl.format(module, decoder, encoder)
        timeit(module, 'de/encoded', number, jsn, import_stmt)

    print(ASCII_BREAK)


if __name__ == '__main__':
    if len(sys.argv) == 3:
        main(int(sys.argv[1]), sys.argv[2])
